==> gradle-src-4.8-1-any.pkg.tar.xz: usr/share/java/gradle/src/language-java/org/gradle/api/internal/tasks/compile/processing/NonIncrementalProcessingStrategy.java <==
/*
 * Copyright 2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.tasks.compile.processing;

import org.gradle.api.internal.tasks.compile.incremental.processing.AnnotationProcessingResult;

import javax.annotation.processing.RoundEnvironment;
import javax.lang.model.element.Element;
import javax.lang.model.element.TypeElement;
import java.util.Set;

/**
 * The strategy used for non-incremental annotation processors.
 * @see NonIncrementalProcessor
 */
public class NonIncrementalProcessingStrategy extends IncrementalProcessingStrategy {
    private final String name;
    private final AnnotationProcessingResult result;

    NonIncrementalProcessingStrategy(String name, AnnotationProcessingResult result) {
        super(result);
        this.name = name;
        this.result = result;
    }

    @Override
    public void recordProcessingInputs(Set<String> supportedAnnotationTypes, Set<? extends TypeElement> annotations, RoundEnvironment roundEnv) {
        result.setFullRebuildCause(name + " is not incremental");
    }

    @Override
    public void recordGeneratedType(CharSequence name, Element[] originatingElements) {

    }
}

==> gradle-src-5.2.1-1.0-any.pkg.tar.xz: usr/share/java/gradle/src/language-java/org/gradle/api/internal/tasks/compile/processing/NonIncrementalProcessingStrategy.java <==
/*
 * Copyright 2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.tasks.compile.processing;

import org.gradle.api.internal.tasks.compile.incremental.processing.AnnotationProcessorResult;

import javax.annotation.processing.RoundEnvironment;
import javax.lang.model.element.Element;
import javax.lang.model.element.TypeElement;
import java.util.Set;

import static org.gradle.api.internal.tasks.compile.incremental.processing.IncrementalAnnotationProcessorType.UNKNOWN;

/**
 * The strategy used for non-incremental annotation processors.
 * @see NonIncrementalProcessor
 */
public class NonIncrementalProcessingStrategy extends IncrementalProcessingStrategy {
    private final String name;

    NonIncrementalProcessingStrategy(String name, AnnotationProcessorResult result) {
        super(result);
        this.name = name;
        result.setType(UNKNOWN);
    }

    @Override
    public void recordProcessingInputs(Set<String> supportedAnnotationTypes, Set<? extends TypeElement> annotations, RoundEnvironment roundEnv) {
        result.setFullRebuildCause(name + " is not incremental");
    }

    @Override
    public void recordGeneratedType(CharSequence name, Element[] originatingElements) {

    }
}
